@@ -2,8 +2,9 @@ from copy import deepcopy
 
 
 def remove_key(value: dict, removed_key='self') -> dict:
-    if removed_key in value:
-        value.pop(removed_key)
+    for k in removed_key.split(","):
+        if k in value:
+            value.pop(k)
     return value
 
 
