@@ -229,7 +229,7 @@ class ReconnectingWebSocket:
                 elif res.get("op") == WebSocketOP.AUTH and res.get('err-code') == 0:
                     self._complete_auth = True
 
-                if res and res.get('err-code', 0) > 0:
+                if res and res.get('err-code'):
                     logging.error(res)
 
         return res
